==> kwap-common-0.6.2.crate: kwap-common-0.6.2/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.6.2 (2022-05-15)


### Features

* **common:** add Map trait ([#115](https://github.com/clov-coffee/kwap/issues/115)) ([82b8eec](https://github.com/clov-coffee/kwap/commit/82b8eecc3a3149c75db6dfed4f3a5a60ebf17fbd))

### 0.6.1 (2022-04-26)


### Features

* **kwap_common:** move utility things to common ([#70](https://github.com/clov-coffee/kwap/issues/70)) ([508998e](https://github.com/clov-coffee/kwap/commit/508998e01653774b9b1ca52aeb3c8ab1292ac0b6))

## 0.6.0 (2022-01-03)


### ⚠ BREAKING CHANGES

* **common:** array should not be generic (#41)

### Features

* **common:** array should not be generic ([#41](https://github.com/clov-coffee/kwap/issues/41)) ([ce2b4a8](https://github.com/clov-coffee/kwap/commit/ce2b4a8593696f29bc724402c81ca941363a8733))

## 0.5.0 (2022-01-03)


### ⚠ BREAKING CHANGES

* **common:** array type should be simple (#40)

### Features

* **common:** array type should be simple ([#40](https://github.com/clov-coffee/kwap/issues/40)) ([f38af97](https://github.com/clov-coffee/kwap/commit/f38af9767480408cce1b67d99b3ff9f9b4793e09))

## 0.4.0 (2021-12-31)


### ⚠ BREAKING CHANGES

* **common:** add index bounds to array (#36)

### Features

* **common:** add index bounds to array ([#36](https://github.com/clov-coffee/kwap/issues/36)) ([4198930](https://github.com/clov-coffee/kwap/commit/419893098eb526307b22f414f5d4399256f716d2))

## 0.3.0 (2021-12-31)


### ⚠ BREAKING CHANGES

* **common:** add insert trait + bound to array (#35)

### Features

* **common:** add insert trait + bound to array ([#35](https://github.com/clov-coffee/kwap/issues/35)) ([5e8f5ee](https://github.com/clov-coffee/kwap/commit/5e8f5ee40db84d45d224ff33af22cd08b5799365))

### 0.2.6 (2021-12-31)

==> kwap-common-0.6.3.crate: kwap-common-0.6.3/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.6.3 (2022-05-16)


### Features

* **common:** impl Map for BTreeMap ([#116](https://github.com/clov-coffee/kwap/issues/116)) ([7ccc1f6](https://github.com/clov-coffee/kwap/commit/7ccc1f6d47dc2211d28f7b18f3f71b10ea356582))

### 0.6.2 (2022-05-15)


### Features

* **common:** add Map trait ([#115](https://github.com/clov-coffee/kwap/issues/115)) ([82b8eec](https://github.com/clov-coffee/kwap/commit/82b8eecc3a3149c75db6dfed4f3a5a60ebf17fbd))

### 0.6.1 (2022-04-26)


### Features

* **kwap_common:** move utility things to common ([#70](https://github.com/clov-coffee/kwap/issues/70)) ([508998e](https://github.com/clov-coffee/kwap/commit/508998e01653774b9b1ca52aeb3c8ab1292ac0b6))

## 0.6.0 (2022-01-03)


### ⚠ BREAKING CHANGES

* **common:** array should not be generic (#41)

### Features

* **common:** array should not be generic ([#41](https://github.com/clov-coffee/kwap/issues/41)) ([ce2b4a8](https://github.com/clov-coffee/kwap/commit/ce2b4a8593696f29bc724402c81ca941363a8733))

## 0.5.0 (2022-01-03)


### ⚠ BREAKING CHANGES

* **common:** array type should be simple (#40)

### Features

* **common:** array type should be simple ([#40](https://github.com/clov-coffee/kwap/issues/40)) ([f38af97](https://github.com/clov-coffee/kwap/commit/f38af9767480408cce1b67d99b3ff9f9b4793e09))

## 0.4.0 (2021-12-31)


### ⚠ BREAKING CHANGES

* **common:** add index bounds to array (#36)

### Features

* **common:** add index bounds to array ([#36](https://github.com/clov-coffee/kwap/issues/36)) ([4198930](https://github.com/clov-coffee/kwap/commit/419893098eb526307b22f414f5d4399256f716d2))

## 0.3.0 (2021-12-31)


### ⚠ BREAKING CHANGES

* **common:** add insert trait + bound to array (#35)

### Features

* **common:** add insert trait + bound to array ([#35](https://github.com/clov-coffee/kwap/issues/35)) ([5e8f5ee](https://github.com/clov-coffee/kwap/commit/5e8f5ee40db84d45d224ff33af22cd08b5799365))

### 0.2.6 (2021-12-31)
